#
# spec file for package cmpi-bindings
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo


Url:            http://github.com/kkaempf/cmpi-bindings

Name:           cmpi-bindings
Version:        1.0.2
Release:        lp152.2.6
Summary:        Adapter to write and run CMPI-type CIM providers
License:        BSD-3-Clause AND CPL-1.0
Group:          Development/Libraries/Other
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  gcc-c++

# We need swig threads support.
BuildRequires:  swig >= 1.3.34

BuildRequires:  sblim-cmpi-devel

BuildRequires:  perl
BuildRequires:  python-devel

%if 0%{?rhel_version} > 0
BuildRequires:  -vim
%endif

%if 0%{?fedora} + 0%{?rhel_version} + 0%{?centos_version}  > 0

BuildRequires:  curl-devel
BuildRequires:  pkgconfig
BuildRequires:  ruby
BuildRequires:  ruby-devel
BuildRequires:  ruby-libs

%if 0%{?rhel_version} < 500
# rdoc needs irb/slex in rhel4
BuildRequires:  irb
%endif

%if (0%{?rhel_version} >= 500 && 0%{?rhel_version} < 600) || 0%{?centos_version} >= 500 || 0%{?fedora} < 17
# rdoc is separate from rhel5 on
BuildRequires:  ruby-rdoc
%endif

%if 0%{?fedora} > 18
BuildRequires:  rubypick
%endif

%if 0%{?fedora} || 0%{?rhel_version} >= 600 || 0%{?centos_version} >= 600
BuildRequires:  perl-devel
%endif

%endif

%if 0%{?suse_version} > 0

%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif

%if 0%{?suse_version} > 1010
BuildRequires:  libcurl-devel
%else
# SLE10
BuildRequires:  curl-devel
%endif

# SLE9
%if 0%{?suse_version} < 920
BuildRequires:  pkgconfig
BuildRequires:  ruby
%else
BuildRequires:  pkg-config
BuildRequires:  ruby-devel
%endif

%endif

Source:         %{name}-%{version}.tar.bz2

%description
-

%prep
%setup -q 

%build

# enforce installed FindRuby

if [ -f /usr/share/cmake/Modules/FindRuby.cmake ]; then
  rm -f cmake/modules/FindRuby.cmake
fi

mkdir build
cd build
cmake -DCMAKE_INSTALL_PREFIX=%_prefix \
      -DLIB=%{_lib} \
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_SKIP_RPATH=1 \
      -DBUILD_RUBY_GEM=no \
      ..
make %{?_smp_mflags}

%install
cd build
mkdir -p %{buildroot}/%{_datadir}/cmpi
%make_install
mkdir -p %{buildroot}/%{_docdir}
%if 0%{?suse_version} < 1500
cp -a swig/ruby/html %{buildroot}/%{_docdir}/cmpi-bindings-ruby-docs
%endif

%package -n cmpi-bindings-ruby
Summary:        Adapter to write and run CMPI-type CIM providers in Ruby
# for the debug package. we dont use debug_package_requires here as it would enforce to install both packages.
Group:          Development/Languages/Ruby
Provides:       %{name} = %{version}-%{release}
%if 0%{?ruby_sitelib} == 0
%{!?ruby_sitelib: %global ruby_sitelib %(ruby -r rbconfig -e 'vd = RbConfig::CONFIG["vendorlibdir"]; print(vd ? vd : RbConfig::CONFIG["sitelibdir"])')}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -r rbconfig -e 'vad = RbConfig::CONFIG["vendorarchdir"]; print(vad ? vad : RbConfig::CONFIG["sitearchdir"])')}
%endif

%description -n cmpi-bindings-ruby
Adapter to write and run CMPI-type CIM providers in Ruby

%files -n cmpi-bindings-ruby
%defattr(-,root,root,-)
%dir %{_libdir}/cmpi
%{_libdir}/cmpi/librbCmpiProvider.so
%{ruby_sitelib}/cmpi.rb
%dir %{ruby_sitelib}/cmpi
%dir %{ruby_sitelib}/cmpi/providers
%{ruby_sitelib}/cmpi/provider.rb

%if 0%{?suse_version} < 1500
# ruby 2.5.0 broke swig-rdoc
%package -n cmpi-bindings-ruby-doc
Summary:        RDoc-style documentation for cmpi-bindings-ruby
Group:          Documentation/HTML

%description -n cmpi-bindings-ruby-doc
RDoc-style documentation for cmpi-bindings-ruby

%files -n cmpi-bindings-ruby-doc
%defattr(-,root,root,-)
%dir %{_docdir}/cmpi-bindings-ruby-docs
%{_docdir}/cmpi-bindings-ruby-docs
%endif

%package -n cmpi-bindings-pywbem
Summary:        Adapter to write and run CMPI-type CIM providers in Python
# for the debug package. we dont use debug_package_requires here as it would enforce to install both packages.
Group:          Development/Languages/Python
Provides:       %{name} = %{version}-%{release}
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py_requires: %define py_requires Requires: python}
%{py_requires}

%description -n cmpi-bindings-pywbem
-

%files -n cmpi-bindings-pywbem
%defattr(-,root,root,-)
%dir %{_libdir}/cmpi
%{_libdir}/cmpi/libpyCmpiProvider.so
%dir %{_datadir}/cmpi
%{python_sitelib}/cmpi_pywbem_bindings.py*
%{python_sitelib}/cmpi.py*

%package -n cmpi-bindings-perl
Requires:       perl = %{perl_version}
Summary:        Adapter to write and run CMPI-type CIM providers in Perl
# for the debug package. we dont use debug_package_requires here as it would enforce to install both packages.
Group:          Development/Languages/Perl
Provides:       %{name} = %{version}-%{release}

%description -n cmpi-bindings-perl
-

%files -n cmpi-bindings-perl
%defattr(-,root,root,-)
%dir %{_libdir}/cmpi
%{_libdir}/cmpi/libplCmpiProvider.so
%dir %{_datadir}/cmpi
%{perl_vendorlib}/cmpi-bindings.pl
%{perl_vendorlib}/cmpi.pm

%changelog
* Wed Aug  8 2018 jengelh@inai.de
- Replace old $RPM_* shell vars by macros.
* Tue May 29 2018 kkaempf@suse.com
- Update to 1.0.2
  - disable ruby documentation for Ruby 2.5.0
    (rdoc-6.0.1 breaks swig documentation hack)
* Thu Jan 29 2015 kkaempf@suse.com
- Update to 1.0.1
  - fix comment characters in .i files for swig 3.0.4
    (dimstar@opensuse.org)
    this includes cmpi-bindings-swig-3.0.patch
  - improve documentation coverage
* Mon Jan 26 2015 dimstar@opensuse.org
- Add cmpi-bindings-swig-3.0.patch: Fix build with SWIG 3.0.
* Wed Jun 25 2014 kkaempf@suse.com
- Update to 1.0.0
  - Transport CMPIStatus information from Ruby to CMPI API.
  - Add Ruby classes representing CMPI error codes.
  - Capture call results and raise proper exceptions.
  - Fix Fedora 20 build
* Wed Feb  5 2014 kkaempf@suse.com
- Update to 0.9.9
  - Support rdoc from Ruby 2.1
* Thu Dec 12 2013 kkaempf@suse.com
- Update to 0.9.8
  - Create Ruby documentation
  - Split off package cmpi-bindings-ruby-docs
  - Fix Fedora 19 build
* Wed Oct  9 2013 kkaempf@suse.com
- Update to 0.9.7
  Catch and log Ruby exceptions caused by invoke method type
  conversions.
* Wed Oct  9 2013 kkaempf@suse.com
- Update to 0.9.6
  Return correct status for failed method invocation in Ruby.
* Thu Sep 26 2013 kkaempf@suse.com
- Drop explicit ruby(abi) requires (bnc#842433)
* Thu Apr 11 2013 kkaempf@suse.com
- Update to 0.9.5
  Fix CMPISelectExp also in cmpi_provider.c (indication filters)
* Thu Apr 11 2013 kkaempf@suse.com
- Update to 0.9.4
  - Fix nasty bugs in CMPIObjectPath constructor if reference
    already contained string properties.
* Wed Apr 10 2013 kkaempf@suse.com
- Update to 0.9.3
  - Raise exception on nil assignment to numeric properties
* Tue Apr  9 2013 kkaempf@suse.com
- Update to 0.9.2
  Add projections to CMPISelectExp (to support filtering by
  property in execQuery)
* Tue Apr  9 2013 kkaempf@suse.com
- Update to 0.9.1
  CMPISelectExp constructor and match (to support execQuery in
  providers)
* Tue Mar 19 2013 cfarrell@suse.com
- license update: BSD-3-Clause and CPL-1.0
  The SUSE licensed code (.mof files) are CPL-1.0, not EPL-1.0
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Thu Feb 14 2013 kkaempf@suse.com
- Update to 0.9.0
  - Added full testsuite
  - Improved CMPI_DateTime handling in Ruby
  - bug fixes
* Mon Oct  1 2012 kkaempf@suse.com
- no Ruby in RHEL6 in OBS ?!
* Mon Aug  6 2012 kkaempf@suse.com
- fix CentOS/RHEL 6 build
* Fri Jul  6 2012 kkaempf@suse.com
- Adapt trace level according to CMPI_BINDINGS_TRACE_LEVEL
  environment variable (bnc#767533)
* Sun May 27 2012 kkaempf@suse.com
- Update to 0.5.4
  - Fix constructor/destructor names (to adapt to swig 2.0.5 rules)
* Thu May 24 2012 kkaempf@suse.com
- Update to 0.5.3
  - Implement CMPI_DateTime <-> Ruby conversions
  - Fix Char16 handling
  - Plug one memory leak
  - Support Ruby 1.9
  - disable html doc creation in Ruby 1.9
* Fri May  4 2012 kkaempf@suse.com
- Update to 0.5.2
  - Fix CMPIValue <-> CMPIData confusion in Python (Jan Safranek)
  - Don't build RPM and GEM in parallel
* Mon Mar 12 2012 kkaempf@suse.com
- Update to 0.5.1
  Confine data_data to wrapping CMPIData, don't convert the value
  (fixes issue #3 reported by mibanescu)
* Mon Mar  5 2012 kkaempf@suse.com
- Update to 0.5.0
  Bugfixes
  - plug many memory leaks
  - proper handling of Null value in Python
  Features
  - switch to a *much* simpler Ruby API
  - provide cmpi-bindings as a Ruby gem
* Sun Oct  2 2011 kkaempf@suse.com
- Proper error handling in CMPIObjectPath constructor
- v 0.4.18
* Fri Sep 30 2011 kkaempf@suse.com
- Release CMPI objects properly
- Fix CMPIObjectPath and CMPIInstance constructors
- v 0.4.17
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jul  6 2011 kkaempf@novell.com
- Fix Python memory leaks, remove excessive INCREFs
  (by Mihai Ibanescu)
- v 0.4.16
* Wed Jul  6 2011 kkaempf@novell.com
- Fix Python backend loading issue.
- v 0.4.15
* Fri Jun 10 2011 kkaempf@suse.de
- Don't pass NULL back to Python, use PyNone instead.
  (upstream issue #1)
- Correctly handle state of CMPIData and raise exceptions in
  case of notFound or badValue when returning CMPIData to the
  target language.
- v 0.4.14
* Wed Jun  8 2011 kkaempf@suse.de
- Replace to_s() with __str__() in Python where applicable
- v 0.4.13
* Wed Dec 22 2010 kkaempf@novell.com
- Require CMPIBroker in calls to CMPIObjectPath and CMPIInstance
  constructors (Perl and Python only)
- v 0.4.12
* Tue Dec 21 2010 kkaempf@novell.com
- Provide equality operator for CMPIBroker
- v 0.4.11
* Fri Oct  8 2010 kkaempf@novell.com
- Adapt to work with Swig 2.x
* Wed Aug  4 2010 kkaempf@novell.com
- Install Ruby files into vendor- or site-dir
  Create cmpi/provider.rb and cmpi/providers dir for Ruby providers
* Fri Jul 30 2010 kkaempf@novell.com
- simplify the name
  - use 'cmpi' for Ruby
  - use 'cmpi-bindings' for Perl
  - keep 'cmpi_pywbem_bindings' for Python since pywbem is needed
* Fri Jul 30 2010 kkaempf@novell.com
- Fix SLE10 build.
* Wed Mar 17 2010 coolo@novell.com
- various fixes for other distributions
* Wed Nov  4 2009 bwhiteley@suse.de
- Fixed References up-calls in python bindings (bnc#552571)
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue Dec 23 2008 bwhiteley@suse.de
- Update to official 0.4.0 release.
* Fri Nov  7 2008 bwhiteley@suse.de
- Better handling of import errors.
- Code cleanup.
* Thu Oct 23 2008 npaxton@novell.com
- Update to latest code, prep for release for python bindings
- Indication support in python
- Bump version to 0.4.0
* Thu Oct 16 2008 kkaempf@suse.de
- Complete Ruby bindings.
- Small runtime improvement for Python.
- Bump version to 0.3.0
* Mon Sep 29 2008 kkaempf@suse.de
- refactor cmpi_provider_{python,ruby}.c,
  move common lines (75%%) to cmpi_provider.c and target language
  specific lines (25%%) to target_{python,ruby}.c
* Sat Sep 27 2008 bwhiteley@suse.de
- Update to latest code.
- Better error handling.
* Fri Sep 19 2008 kkaempf@suse.de
- rename .py filename to reflect 'pywbem' dependency.
- fix build for SLE10 in OpenSUSE build service.
* Wed Sep 17 2008 mrueckert@suse.de
- provide the main package for the debug package. we dont use
  debug_package_requires here as it would enforce to install both
  packages.
* Tue Sep 16 2008 bwhiteley@suse.de  
- Refactered broker wrapping.
- Lots of cleanup.
* Thu Sep 11 2008 kkaempf@suse.de
- Support Python threads, do proper locking
- Bump version to 0.2.0
* Tue Sep  2 2008 kkaempf@suse.de
- Initial package.
